@@ -49,7 +49,7 @@ class OpenProvider(object):
         # Set up the API client
         self.session = requests.Session()
         self.session.verify = True
-        self.session.headers['User-Agent'] = 'openprovider.py/0.8.0'
+        self.session.headers['User-Agent'] = 'openprovider.py/0.10.0'
 
         # Initialize and add all modules.
         for old_name, module in MODULE_MAPPING.items():
@@ -93,7 +93,7 @@ class OpenProvider(object):
             desc = tree.reply.desc
             code = tree.reply.code
             data = getattr(tree.reply, 'data', '')
-            raise klass("{0} ({1}) {2}".format(desc, code, data))
+            raise klass("{0} ({1}) {2}".format(desc, code, data), code)
 
 
 def _get_env(key, account):
